@@ -1,8 +1,12 @@
-// [[file:../gut.note::*mods][mods:1]]
+// [[file:../gut.note::36e53031][36e53031]]
+pub mod cli;
+pub mod config;
+pub mod fs;
+pub mod logger;
+pub mod utils;
+// 36e53031 ends here
 
-// mods:1 ends here
-
-// [[file:../gut.note::*pub][pub:1]]
+// [[file:../gut.note::b07726f0][b07726f0]]
 pub mod prelude {
     pub use crate::config::Configure;
 
@@ -25,15 +29,16 @@ pub mod prelude {
     // for write! and writeln! macros
     // avoid name conflict with std::io::Write
     pub use std::fmt::Write as FmtWrite;
+    pub use std::io::{Read, Write};
 
     // FooBar::from_str
     pub use std::str::FromStr;
+
+    // provides shell_escape_lossy method for `Path`
+    pub use crate::fs::{ShellEscapeExt, ShellEscapeLossyExt};
 }
 
-pub mod cli;
-pub mod config;
-pub mod fs;
-
+// re-exports external crates
 pub use itertools;
 
 /// Similar to dbg! macro, but with logging (info!)
@@ -43,4 +48,4 @@ macro_rules! log_dbg {
         info!("{}:{}", file!(), line!());
     };
 }
-// pub:1 ends here
+// b07726f0 ends here
